==> nextcloud-29.0.5.tgz: nextcloud/apps/comments/l10n/id.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentar",
    "You commented" : "Anda berkomentar",
    "{author} commented" : "{Pengarang} berkomentar",
    "You commented on %1$s" : "Anda berkomentar pada %1$s",
    "You commented on {file}" : "Anda berkomentar pada {file} ",
    "%1$s commented on %2$s" : "%1$s dikomentari pada %2$s",
    "{author} commented on {file}" : "{pengarang} berkomentar pada {file}",
    "<strong>Comments</strong> for files" : "<strong>komentar</strong> pada file",
    "{user} mentioned you in a comment on \"{file}\"" : "{pengguna} menyebut Anda dalam sebuah komentar pada \"{file}\" ",
    "Files app plugin to add comments to files" : "Plugin aplikasi file untuk menambah komentar pada file",
    "Edit comment" : "Sunting komentar",
    "Delete comment" : "Hapus komentar",
    "Cancel edit" : "Batal sunting",
    "Post comment" : "Posting komentar",
    "No comments yet, start the conversation!" : "Belum ada yang berkomentar, mulailah perbincangan!",
    "No more messages" : "Tidak ada pesan lagi",
    "Retry" : "Ulangi",
    "Unable to load the comments list" : "Tidak dapat memuat daftar komentar",
    "_1 new comment_::_{unread} new comments_" : ["komentar baru {belum terbaca}"],
    "Comment" : "Komentar",
    "An error occurred while trying to edit the comment" : "Terjadi kesalahan ketika mencoba menyunting komentar",
    "Comment deleted" : "Komentar dihapus",
    "An error occurred while trying to delete the comment" : "Terjadi kesalahan ketika mencoba untuk menghapus komentar",
    "An error occurred while trying to create the comment" : "Terjadi kesalahan ketika mencoba untuk membuat komentar",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Anda disebut pada \"{file}\", dalam sebuah komentar oleh pengguna yang sejak itu telah dihapus"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/comments/l10n/id.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentar",
    "You commented" : "Anda berkomentar",
    "{author} commented" : "{author} berkomentar",
    "You commented on %1$s" : "Anda berkomentar pada %1$s",
    "You commented on {file}" : "Anda berkomentar pada {file} ",
    "%1$s commented on %2$s" : "%1$s dikomentari pada %2$s",
    "{author} commented on {file}" : "{author} berkomentar pada {file}",
    "<strong>Comments</strong> for files" : "<strong>komentar</strong> pada file",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} menyebut Anda dalam sebuah komentar pada \"{file}\" ",
    "Files app plugin to add comments to files" : "Plugin aplikasi file untuk menambah komentar pada file",
    "Edit comment" : "Sunting komentar",
    "Delete comment" : "Hapus komentar",
    "Cancel edit" : "Batal sunting",
    "Post comment" : "Posting komentar",
    "No comments yet, start the conversation!" : "Belum ada yang berkomentar, mulailah perbincangan!",
    "No more messages" : "Tidak ada pesan lagi",
    "Retry" : "Ulangi",
    "Unable to load the comments list" : "Tidak dapat memuat daftar komentar",
    "Comment" : "Komentar",
    "An error occurred while trying to edit the comment" : "Terjadi kesalahan ketika mencoba menyunting komentar",
    "Comment deleted" : "Komentar dihapus",
    "An error occurred while trying to delete the comment" : "Terjadi kesalahan ketika mencoba untuk menghapus komentar",
    "An error occurred while trying to create the comment" : "Terjadi kesalahan ketika mencoba untuk membuat komentar"
},
"nplurals=1; plural=0;");
